@@ -1,27 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "monitor.h"
 
@@ -272,7 +251,7 @@ bool Monitor::isSameResolution(const Resolution &r1, const Resolution &r2)
 
 bool Monitor::isSameRatefresh(const Resolution &r1, const Resolution &r2)
 {
-    return fabs(r1.rate() - r2.rate()) < 0.000001;
+    return QString::number(r1.rate(), 'g', 4) == QString::number(r2.rate(), 'g', 4);
 }
 
 bool Monitor::hasResolution(const Resolution &r)
@@ -289,11 +268,12 @@ bool Monitor::hasResolution(const Resolution &r)
 bool Monitor::hasResolutionAndRate(const Resolution &r)
 {
     for (auto m : m_modeList) {
-        if (fabs(m.rate() - r.rate()) < 0.000001 && m.width() == r.width() && m.height() == r.height()) {
+        if (QString::number(m.rate(), 'g', 4) == QString::number(r.rate(), 'g', 4)  && m.width() == r.width() && m.height() == r.height()) {
             return true;
         }
     }
 
+
     return false;
 }
 
