@@ -1,27 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "personalizationwork.h"
 #include "model/thememodel.h"
@@ -39,7 +18,8 @@ using namespace dcc::personalization;
 
 const QString Service = "com.deepin.daemon.Appearance";
 const QString Path    = "/com/deepin/daemon/Appearance";
-const QString effectMoveWindowArg = "kwin4_effect_translucency";
+const QString EffectMoveWindowArg = "kwin4_effect_translucency";
+const QString StrIsOpenWM = "deepin wm";
 
 static const std::vector<int> OPACITY_SLIDER {
     0,
@@ -116,6 +96,13 @@ PersonalizationWork::PersonalizationWork(PersonalizationModel *model, QObject *p
         });
     };
 
+    if (m_wmSwitcher && m_wmSwitcher->CurrentWM() == StrIsOpenWM && m_effects) {
+        bool isMoveWindow = m_effects->isEffectLoaded(EffectMoveWindowArg);
+        qDebug() << Q_FUNC_INFO << isMoveWindow;
+        m_model->setIsMoveWindow(isMoveWindow);
+        m_model->setIsMoveWindowDconfig(isMoveWindow);
+    }
+
     m_themeModels["gtk"]           = windowTheme;
     m_themeModels["icon"]          = iconTheme;
     m_themeModels["cursor"]        = cursorTheme;
@@ -204,18 +191,6 @@ void PersonalizationWork::refreshWMState()
 {
     QDBusPendingCallWatcher *wmWatcher = new QDBusPendingCallWatcher(m_wmSwitcher->CurrentWM(), this);
     connect(wmWatcher, &QDBusPendingCallWatcher::finished, this, &PersonalizationWork::onGetCurrentWMFinished);
-
-    if (!m_effects) {
-        qWarning() << "The Interface of org::kde::kwin::Effects is nullptr.";
-        return;
-    }
-
-    bool isMoveWindow = m_effects->isEffectLoaded(effectMoveWindowArg);
-    qDebug() << Q_FUNC_INFO << isMoveWindow;
-    m_model->setIsMoveWindow(isMoveWindow);
-
-    //TODO: 关联打开移动窗口功能信号(kwin4_effect_translucency)，实时响应变化
-    //目前窗管无法提供该信号，待后续窗管提供信号后再处理
 }
 
 void PersonalizationWork::FontSizeChanged(const double value) const
@@ -297,14 +272,35 @@ void PersonalizationWork::onRefreshedChanged(const QString &type)
 
 void PersonalizationWork::onToggleWM(const QString &wm)
 {
-    qDebug() << "onToggleWM: " << wm;
-    m_model->setIs3DWm(wm == "deepin wm");
+    bool is3D = wm == StrIsOpenWM;
+    qDebug() << "onToggleWM: " << wm << is3D;
+    m_model->setIs3DWm(is3D);
+}
+
+void PersonalizationWork::setMoveWindow(bool state)
+{
+    if (!m_effects) {
+        qWarning() << "The Interface of org::kde::kwin::Effects is nullptr.";
+        return;
+    }
+
+    if (!m_model) {
+        return;
+    }
+
+    if (state) {
+        m_model->setIsMoveWindow(m_model->getIsMoveWindowDconfig());
+    } else {
+        m_model->setIsMoveWindowDconfig(m_model->isMoveWindow());
+        m_model->setIsMoveWindow(false);
+    }
 }
 
 void PersonalizationWork::onWindowWM(bool value)
 {
     qDebug() << "onWindowWM: " << value;
     m_model->setIs3DWm(value);
+    setMoveWindow(value);
 }
 
 void PersonalizationWork::onCompositingAllowSwitch(bool value)
@@ -556,12 +552,14 @@ void PersonalizationWork::movedWindowSwitchWM(bool value)
     }
 
     if (value) {
-        bool isload = m_effects->loadEffect(effectMoveWindowArg);
+        bool isload = m_effects->loadEffect(EffectMoveWindowArg);
         qDebug() << Q_FUNC_INFO << " The effect of  kwin4_effect_translucency is : " << isload;
         m_model->setIsMoveWindow(isload);
+        m_model->setIsMoveWindowDconfig(isload);
     } else {
-        m_effects->unloadEffect(effectMoveWindowArg);
+        m_effects->unloadEffect(EffectMoveWindowArg);
         m_model->setIsMoveWindow(false);
+        m_model->setIsMoveWindowDconfig(false);
     }
 }
 
