@@ -139,6 +139,16 @@ MainWindow::MainWindow(QWidget *parent)
     //Initialize top page view and model
     m_navModel = new QStandardItemModel(m_navView);
     m_navView->setModel(m_navModel);
+    connect(m_navView, &dcc::widgets::MultiSelectListView::notifySelectionChanged, this, [=](const QModelIndex &index) {
+        if (m_currentIndex != index.row()) {
+            m_currentIndex = index.row();
+            qInfo() << " [notifySelectionChanged] index.row : " << index.row();
+            if (!m_bIsNeedChange) {
+                m_bIsNeedChange = true;
+                qInfo() << " [notifySelectionChanged] index.row, m_bIsNeedChange : " << index.row() << m_bIsNeedChange;
+            }
+        }
+    });
     connect(m_navView, &DListView::activated, this, &MainWindow::onFirstItemClick);
     connect(m_navView, &DListView::clicked, m_navView, &DListView::activated);
 
@@ -148,9 +158,6 @@ MainWindow::MainWindow(QWidget *parent)
     m_searchWidget->lineEdit()->setAccessibleName("SearchModuleLineEdit");
     GSettingWatcher::instance()->bind("mainwindowSearchEdit", m_searchWidget);
 
-    m_currentIndex.first = m_navView->viewMode();
-    m_currentIndex.second = m_navView->currentIndex();
-
     DTitlebar *titlebar = this->titlebar();
     auto widhetlist = titlebar->children();
     for (auto child : widhetlist) {
@@ -298,7 +305,10 @@ void MainWindow::setPrimaryScreen(QScreen *screen)
     m_primaryScreen = screen;
     updateWinsize();
     connect(m_primaryScreen, &QScreen::geometryChanged, this, &MainWindow::updateWinsize);
-    connect(m_primaryScreen, &QScreen::availableGeometryChanged, this, &MainWindow::updateWinsize);
+    // 主屏变化后，根据新主屏的分辨率移动窗口居中
+    connect(qApp, &QGuiApplication::primaryScreenChanged, this, [this] {
+        updateWinsize(m_primaryScreen->geometry());
+    });
 }
 
 QScreen *MainWindow::primaryScreen() const
@@ -756,14 +766,10 @@ bool MainWindow::eventFilter(QObject *watched, QEvent *event)
             return true;
         }
     } else if (event->type() == QEvent::MouseButtonRelease) {
-        QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
-        if (mouseEvent->button() == Qt::MouseButton::LeftButton) {
-            if (m_currentIndex.first != m_navView->viewMode() ||
-                m_currentIndex.second != m_navView->currentIndex()) {
-                m_currentIndex.first = m_navView->viewMode();
-                m_currentIndex.second = m_navView->currentIndex();
-                onFirstItemClick(m_currentIndex.second);
-            }
+        if (static_cast<QMouseEvent *>(event)->button() == Qt::MouseButton::LeftButton && m_bIsNeedChange) {
+            m_bIsNeedChange = false;
+            qInfo() << " [eventFilter] MouseButtonRelease, currentIndex : " << m_navView->currentIndex().row();
+            onFirstItemClick(m_navView->currentIndex());
         }
     }
 
@@ -1235,11 +1241,13 @@ void MainWindow::updateViewBackground()
 
 void MainWindow::onFirstItemClick(const QModelIndex &index)
 {
-    if (index.row() < 0 || !m_modules[index.row()].first) {
+    if (index.row() < 0 || m_modules.count() <= 0) {
         return;
     }
-
     ModuleInterface *inter = m_modules[index.row()].first;
+    if (!inter) {
+        return;
+    }
 
     if (!m_contentStack.isEmpty() && m_contentStack.first().first == inter) {
         m_navView->setFocus();
