@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     liuhong <liuhong_cm@deepin.com>
- *
- * Maintainer: liuhong <liuhong_cm@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "createaccountpage.h"
 #include "widgets/titlelabel.h"
@@ -82,6 +65,7 @@ CreateAccountPage::CreateAccountPage(dcc::accounts::AccountsWorker *accountsWork
     m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     m_scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     m_scrollArea->setContentsMargins(0, 0, 0, 0);
+    m_scrollArea->setBackgroundRole(QPalette::Base);
     mainContentLayout->addWidget(m_scrollArea);
 
     m_tw = new QWidget(this);
@@ -324,10 +308,10 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
     }
 
     m_nameEdit->lineEdit()->setPlaceholderText(tr("Required"));//必填
-    m_fullnameEdit->lineEdit()->setPlaceholderText(tr("optional"));//选填
+    m_fullnameEdit->lineEdit()->setPlaceholderText(tr("Optional"));//选填
     m_passwdEdit->lineEdit()->setPlaceholderText(tr("Required"));//必填
     m_repeatpasswdEdit->lineEdit()->setPlaceholderText(tr("Required"));//必填
-    m_passwdTipsEdit->lineEdit()->setPlaceholderText(tr("optional"));//选填
+    m_passwdTipsEdit->lineEdit()->setPlaceholderText(tr("Optional"));//选填
 }
 
 void CreateAccountPage::showGroupList(const QString &index)
