@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     liuhong <liuhong_cm@deepin.com>
- *
- * Maintainer: liuhong <liuhong_cm@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #pragma once
 
@@ -110,8 +93,8 @@ protected:
 
 private Q_SLOTS:
     bool checkName();
-    bool checkFullname();
-    bool checkPassword(DPasswordEdit *edit, bool &needShowSafetyPage);
+    bool checkFullname(bool showTips = true);
+    bool checkPassword(DPasswordEdit *edit, bool &needShowSafetyPage, bool showTips = true);
 
 private:
     dcc::accounts::User *m_newUser;
