@@ -61,7 +61,7 @@ Q_SIGNALS:
     void requestStopEnroll(const QString &thumb);
     void requestReEnrollThumb();
     void requestEnrollThumb();
-    void requesetCloseDlg(const QString &name);
+    void requestCloseDlg(const QString &name);
 
 private:
     QTimer *m_timer;
