@@ -7,14 +7,11 @@
 #include "interface/namespace.h"
 #include "widgets/titlelabel.h"
 #include "widgets/buttontuple.h"
-#include "modules/authentication/widgets/disclaimersitem.h"
 #include "modules/authentication/charamangermodel.h"
-
-#include <DSuggestButton>
-#include <DAbstractDialog>
-#include <DTipLabel>
-
 #include <modules/authentication/widgets/irisinfowidget.h>
+#include "biologicalbasedialog.h"
+
+#include <DTipLabel>
 
 QT_BEGIN_NAMESPACE
 class QVBoxLayout;
@@ -34,7 +31,7 @@ using namespace dcc::widgets;
 namespace DCC_NAMESPACE {
 namespace authentication {
 // 虹膜对话框
-class AddIrisInfoDialog : public DTK_WIDGET_NAMESPACE::DAbstractDialog
+class AddIrisInfoDialog : public BiologicalBaseDialog
 {
     Q_OBJECT
 public:
@@ -44,7 +41,7 @@ public:
 
 Q_SIGNALS:
     void requestInputIris();
-    void requesetCloseDlg();
+    void requestCloseDlg();
     void requestStopEnroll();
 
 protected:
@@ -54,6 +51,7 @@ protected:
 private:
     void initWidget();
     void initConnect();
+    void initBioWidget();
 
 public Q_SLOTS:
     void refreshInfoStatusDisplay(dcc::authentication::CharaMangerModel::AddInfoState state);
@@ -62,13 +60,9 @@ public Q_SLOTS:
 
 private:
     dcc::authentication::CharaMangerModel *m_charaModel;
-    QVBoxLayout *m_mainLayout;
     dcc::authentication::IrisInfoWidget *m_irisInfo;
     QLabel *m_resultTips; // 录入结果说明
     QLabel *m_explainTips; // 状态说明信息
-    dcc::authentication::DisclaimersItem *m_disclaimersItem; // 免责声明
-    QPushButton* m_cancelBtn; // 取消
-    DTK_WIDGET_NAMESPACE::DSuggestButton* m_acceptBtn; // 下一步
     dcc::authentication::CharaMangerModel::AddInfoState m_state;
 };
 
