@@ -285,10 +285,7 @@ void DisplayModule::showMultiScreenWidget()
     });
 
     MultiScreenWidget *multiScreenWidget = new MultiScreenWidget();
-    //wayland情况下这里设置父窗口会影响窗口最大化/还原的问题，详见bug 125867
-    if(!QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)){
-        multiScreenWidget->setParent(m_pMainWindow);
-    }
+    multiScreenWidget->setParent(m_pMainWindow);
 
     multiScreenWidget->setModel(m_displayModel);
     connect(multiScreenWidget, &MultiScreenWidget::requestSwitchMode, m_displayWorker, &DisplayWorker::switchMode);
@@ -356,7 +353,6 @@ void DisplayModule::onRequestSetResolution(Monitor *monitor, const int mode)
 {
     Resolution lastRes = monitor->currentMode();
     Resolution firstRes;
-    QString lastFillMode = m_displayModel->primaryMonitor()->currentFillMode();
 
     for (auto res : monitor->modeList()) {
         if (res.id() == mode) {
@@ -392,16 +388,18 @@ void DisplayModule::onRequestSetResolution(Monitor *monitor, const int mode)
     };
 
     tfunc(monitor, firstRes);
-
-    //此处处理调用applyChanges的200ms延时, TimeoutDialog提前弹出的问题
-    QTimer::singleShot(300, monitor, [this, tfunc, monitor, lastRes,lastFillMode]{
-        if (showTimeoutDialog(monitor) == QDialog::Accepted) {
-            m_displayWorker->saveChanges();
-        } else {
-            tfunc(monitor, lastRes);
-            onSetFillMode(lastFillMode);
-        }
-    });
+    if (m_displayModel->primaryMonitor() != nullptr) {
+        QString lastFillMode = m_displayModel->primaryMonitor()->currentFillMode();
+        //此处处理调用applyChanges的200ms延时, TimeoutDialog提前弹出的问题
+        QTimer::singleShot(300, monitor, [this, tfunc, monitor, lastRes,lastFillMode]{
+            if (showTimeoutDialog(monitor) == QDialog::Accepted) {
+                m_displayWorker->saveChanges();
+            } else {
+                tfunc(monitor, lastRes);
+                onSetFillMode(lastFillMode);
+            }
+        });
+    }
 }
 
 void DisplayModule::onSetFillMode(QString currFullMode)
