@@ -120,6 +120,15 @@ MultiScreenWidget::MultiScreenWidget(QWidget *parent)
     QDesktopWidget *desktopwidget = QApplication::desktop();
     connect(desktopwidget,SIGNAL(workAreaResized(int)),this,SLOT(onResetSecondaryScreenDlg()));
 
+    // 仅HDMI屏切换到以HDMI为主屏的扩展模式时，只触发显示模式变化信号，不会触发主屏变化信号，此时只会执行一次initSecondaryScreenDialog，
+    // 此时获取QApplication::screens数据不准确，只获取到一个屏幕，另外一个屏幕无法获取，导致副界面位置不对
+    // 在SecondaryScreenDialog::resetDialog中，m_monitor->getQScreen()为空
+    connect(qApp, &QApplication::screenAdded, this, [ = ]{
+        if (qEnvironmentVariable("XDG_SESSION_TYPE").contains("wayland")) {
+            initSecondaryScreenDialog();
+        }
+    });
+
 }
 
 MultiScreenWidget::~MultiScreenWidget()
@@ -365,25 +374,21 @@ void MultiScreenWidget::initPrimaryList()
 
 void MultiScreenWidget::initSecondaryScreenDialog()
 {
-    if (m_model->displayMode() == EXTEND_MODE) {
-        for (auto dlg : m_secondaryScreenDlgList) {
-            dlg->deleteLater();
-        }
-        m_secondaryScreenDlgList.clear();
+    // 在每次显示模式切换时，先清空m_secondaryScreenDlgList
+    for (auto dlg : m_secondaryScreenDlgList) {
+        dlg->deleteLater();
+    }
 
-        // x11 上 dialog 没有父窗口会导致主程序退出缓慢
-        // wayland上子窗口为适应多屏就不该设置父窗口，由窗管设置
-        QWidget *parent = this;
-        if (!qgetenv("WAYLAND_DISPLAY").isEmpty()) {
-            parent = nullptr;
-        }
+    m_secondaryScreenDlgList.clear();
+
+    if (m_model->displayMode() == EXTEND_MODE) {
         for (const auto &monitor : m_model->monitorList()) {
             if (monitor == m_model->primaryMonitor()) {
                 QTimer::singleShot(0, this, [=] { requestSetMainwindowRect(m_model->primaryMonitor(), true); });
                 continue;
             }
 
-            SecondaryScreenDialog *dlg = new SecondaryScreenDialog(parent);
+            SecondaryScreenDialog *dlg = new SecondaryScreenDialog(this);
             dlg->setAttribute(Qt::WA_WState_WindowOpacitySet);
             dlg->setModel(m_model, monitor);
             connect(dlg, &SecondaryScreenDialog::requestRecognize, this, &MultiScreenWidget::requestRecognize);
@@ -406,7 +411,11 @@ void MultiScreenWidget::initSecondaryScreenDialog()
         if (!qgetenv("WAYLAND_DISPLAY").isEmpty()) {
             QTimer::singleShot(10, this, [=] {
                 for (auto dlg : m_secondaryScreenDlgList) {
+                    dlg->setWindowFlags(Qt::CoverWindow);
                     dlg->show();
+                    QTimer::singleShot(50, dlg, [dlg] { // 此处延时刷新子窗口位置，是因为子窗口在主屏闪现的问题(bug153993)，待窗管处理之后回退
+                        dlg->resetDialog();
+                    });
                 }
             });
         }
