@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2019 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     wubw <wubowen_cm@deepin.com>
- *
- * Maintainer: wubw <wubowen_cm@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "updatesettings.h"
 #include "widgets/settingsgroup.h"
@@ -56,7 +39,6 @@ UpdateSettings::UpdateSettings(UpdateModel *model, QWidget *parent)
     , m_autoDownloadUpdateTips(new DTipLabel(tr("Switch it on to automatically download the updates in wireless or wired network"), this))
     , m_autoCheckSecureUpdateTips(new DTipLabel(tr("Switch it on to only update security vulnerabilities and compatibility issues"), this))
     , m_testingChannelTips(new DTipLabel(tr("Join the internal testing channel to get deepin latest updates")))
-    , m_testingChannelHeadingLabel(new QLabel(tr("Updates from Internal Testing Sources")))
     , m_testingChannelLinkLabel(new QLabel(""))
     , m_autoCleanCache(new SwitchWidget(this))
     , m_dconfig(nullptr)
@@ -85,6 +67,9 @@ UpdateSettings::UpdateSettings(UpdateModel *model, QWidget *parent)
     //~ contents_path /update/Update Settings
     //~ child_page Update Settings
     m_testingChannel = new SwitchWidget(tr("Join Internal Testing Channel"), this);
+    //~ contents_path /update/Update Settings
+    //~ child_page Update Settings
+    m_testingChannelHeadingLabel = new QLabel(tr("Updates from Internal Testing Sources"));
 
     initUi();
     initConnection();
@@ -517,7 +502,12 @@ void UpdateSettings::onTestingChannelCheckChanged(const bool checked)
         dialog->addButton(tr("Leave"), false, DDialog::ButtonWarning);
         dialog->addButton(tr("Cancel"), true, DDialog::ButtonRecommend);
     });
-    Q_EMIT requestCheckCanExitTestingChannel();
+    // 检查有可能会很快完成，对话框一闪而过会给人一种操作出错的感觉
+    // 延迟一秒后再执行检查，可以让人有时间看到对话框，提升用户体验
+    QTimer::singleShot(1000, this,  [ this ] {
+        Q_EMIT requestCheckCanExitTestingChannel();
+    });
+
     connect(dialog, &DDialog::closed, this, [ = ]() {
         // clicked windows close button
         m_testingChannel->setChecked(true);
