@@ -1,42 +1,44 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en_US">
 <context>
     <name>PasswordWidget</name>
     <message>
         <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="45"/>
         <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="128"/>
         <source>Passwords do not match</source>
-        <translation>Passwords do not match</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="54"/>
         <source>The hint is visible to all users. Do not include the password here.</source>
-        <translation>The hint is visible to all users. Do not include the password here.</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="72"/>
         <source>New Password</source>
-        <translation>New Password</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="94"/>
         <source>Repeat Password</source>
-        <translation>Repeat Password</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="102"/>
         <source>Password Hint</source>
-        <translation>Password Hint</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="111"/>
         <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="112"/>
         <source>Required</source>
-        <translation>Required</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="113"/>
         <source>Optional</source>
-        <translation>Optional</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -44,77 +46,77 @@
     <message>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="61"/>
         <source>Password cannot be empty</source>
-        <translation>Password cannot be empty</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="62"/>
         <source>Password must have at least %1 characters</source>
-        <translation>Password must have at least %1 characters</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="63"/>
         <source>Password must be no more than %1 characters</source>
-        <translation>Password must be no more than %1 characters</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="64"/>
         <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
-        <translation>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="65"/>
         <source>No more than %1 palindrome characters please</source>
-        <translation>No more than %1 palindrome characters please</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="66"/>
         <source>No more than %1 monotonic characters please</source>
-        <translation>No more than %1 monotonic characters please</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="67"/>
         <source>No more than %1 repeating characters please</source>
-        <translation>No more than %1 repeating characters please</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="68"/>
         <source>The password should differ from the username</source>
-        <translation>The password should differ from the username</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="74"/>
         <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
-        <translation>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="75"/>
         <source>Password must not contain more than 4 palindrome characters</source>
-        <translation>Password must not contain more than 4 palindrome characters</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="76"/>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="79"/>
         <source>Do not use common words and combinations as password</source>
-        <translation>Do not use common words and combinations as password</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="77"/>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="78"/>
         <source>Create a strong password please</source>
-        <translation>Create a strong password please</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="85"/>
         <source>It does not meet password rules</source>
-        <translation>It does not meet password rules</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/reset-password-dialog/utils.h" line="55"/>
+        <location filename="../src/reset-password-dialog/utils.h" line="71"/>
         <source>It cannot be empty</source>
-        <translation>It cannot be empty</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -122,36 +124,36 @@
     <message>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="102"/>
         <source>Resetting the password will clear the data stored in the keyring</source>
-        <translation>Resetting the password will clear the data stored in the keyring</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="104"/>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="160"/>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="207"/>
         <source>Cancel</source>
-        <translation>Cancel</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="113"/>
         <source>Security Questions</source>
-        <translation>Security Questions</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="148"/>
         <source>Reset Password</source>
-        <translation>Reset Password</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="149"/>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="192"/>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="195"/>
         <source>Next</source>
-        <translation>Next</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="152"/>
         <source>Reset Password By UOS ID</source>
-        <translation>Reset Password By UOS ID</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="153"/>
@@ -160,22 +162,22 @@
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="203"/>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="210"/>
         <source>Reset</source>
-        <translation>Reset</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="159"/>
         <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
-        <translation>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="160"/>
         <source>Confirm and Reset</source>
-        <translation>Confirm and Reset</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="285"/>
         <source>Successfully reset, please log in and unlock with the new password</source>
-        <translation>Successfully reset, please log in and unlock with the new password</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -183,17 +185,17 @@
     <message>
         <location filename="../src/frame/widgets/securitylevelitem.cpp" line="57"/>
         <source>Weak</source>
-        <translation>Weak</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/frame/widgets/securitylevelitem.cpp" line="67"/>
         <source>Medium</source>
-        <translation>Medium</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/frame/widgets/securitylevelitem.cpp" line="77"/>
         <source>Strong</source>
-        <translation>Strong</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -203,47 +205,47 @@
         <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="110"/>
         <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="111"/>
         <source>Required</source>
-        <translation>Required</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="113"/>
         <source>What&apos;s the name of the city where you were born?</source>
-        <translation>What&apos;s the name of the city where you were born?</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="114"/>
         <source>What&apos;s the name of the first school you attended?</source>
-        <translation>What&apos;s the name of the first school you attended?</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="115"/>
         <source>Who do you love the most in this world?</source>
-        <translation>Who do you love the most in this world?</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="116"/>
         <source>What&apos;s your favorite animal?</source>
-        <translation>What&apos;s your favorite animal?</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="117"/>
         <source>What&apos;s your favorite song?</source>
-        <translation>What&apos;s your favorite song?</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="118"/>
         <source>What&apos;s your nickname?</source>
-        <translation>What&apos;s your nickname?</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="168"/>
         <source>Wrong answer</source>
-        <translation>Wrong answer</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="183"/>
         <source>Keep the answer under 30 characters</source>
-        <translation>Keep the answer under 30 characters</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -251,82 +253,82 @@
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="45"/>
         <source>Phone/Email</source>
-        <translation>Phone/Email</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="51"/>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="118"/>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="267"/>
         <source>Get Code</source>
-        <translation>Get Code</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="71"/>
         <source>Connecting to the Internet...</source>
-        <translation>Connecting to the Internet...</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="83"/>
         <source>The user account is not linked to UOS ID</source>
-        <translation>The user account is not linked to UOS ID</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="96"/>
         <source>Network disconnected, please retry after connected</source>
-        <translation>Network disconnected, please retry after connected</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="116"/>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="117"/>
         <source>Required</source>
-        <translation>Required</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="158"/>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="175"/>
         <source>Phone/Email format is incorrect</source>
-        <translation>Phone/Email format is incorrect</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="229"/>
         <source>System error</source>
-        <translation>System error</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="231"/>
         <source>Login expired, please sign in to the UOS ID again</source>
-        <translation>Login expired, please sign in to the UOS ID again</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="233"/>
         <source>Network error</source>
-        <translation>Network error</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="235"/>
         <source>You have reached the number limit to get the code today</source>
-        <translation>You have reached the number limit to get the code today</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="236"/>
         <source>The UOS ID is not linked to a user account</source>
-        <translation>The UOS ID is not linked to a user account</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="270"/>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="312"/>
         <source>Resend (%1s)</source>
-        <translation>Resend (%1s)</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="332"/>
         <source>Failed to get the code</source>
-        <translation>Failed to get the code</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="357"/>
         <source>Wrong verification code</source>
-        <translation>Wrong verification code</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
